@@ -16,7 +16,7 @@
 #-------------------------------------------------------------------------------
 
 from traits.api \
-    import HasPrivateTraits, Str, implements
+    import HasPrivateTraits, Str, provides
 
 from itemplate_choice \
     import ITemplateChoice
